package com.jz.common.utils;


import org.apache.commons.codec.digest.DigestUtils;

import java.io.UnsupportedEncodingException;

/**
 * 
 * @ClassName: MD5SignUtils 
 * @Description: TODO(data + 混淆串，用MD5算法签名) 
 * @author: niulichang
 * @date: 2020年6月12日 下午2:39:51
 * @最后修改人: niulichang
 * @最后修改时间: 2020年6月12日 下午2:39:51
 */
public class MD5SignUtils {

    private static final String DEFAULT_CHARSET = "UTF-8";

    /**
     * 签名
     *
     * @PARAM SRCSTR
     * @PARAM SALT   作为MD5混淆
     * @RETURN
     */
    public static String sign(String srcStr) throws UnsupportedEncodingException {
        return sign(srcStr, DEFAULT_CHARSET);
    }

    /**
     * 签名
     *
     * @param srcStr
     * @param salt   作为MD5混淆
     * @return
     */
    public static String sign(String srcStr, String charset) throws UnsupportedEncodingException {
        return DigestUtils.md5Hex(getContentBytes(srcStr, charset));
    }

    /**
     * 签名字符串
     * @param text 需要签名的字符串
     * @param sign 签名结果
     * @param salt 密钥
     * @param input_charset 编码格式
     * @return 签名结果
     */
    public static boolean verify(String text, String sign, String input_charset) {
        String mysign = DigestUtils.md5Hex(getContentBytes(text, input_charset));
        if(mysign.equals(sign)) {
            return true;
        }
        else {
            return false;
        }
    }

    /**
     * @param content
     * @param charset
     * @return
     * @throws UnsupportedEncodingException
     */
    private static byte[] getContentBytes(String content, String charset) {
        if (charset == null || "".equals(charset)) {
            return content.getBytes();
        }
        try {
            return content.getBytes(charset);
        } catch (UnsupportedEncodingException e) {
            throw new RuntimeException("MD5签名过程中出现错误,指定的编码集不对,您目前指定的编码集是:" + charset);
        }
    }
}
